@@ -30,7 +30,7 @@ sub result {
     return if ($result->is_plan);
 
     # when we get the next test process the previous one
-    $self->_flush_queue if ($result->is_test && $self->{queue});
+    $self->_flush_queue if ($result->is_test && $self->{_junit_queue});
 
     # except for a few things we don't want to process as a "test case", add
     # the test result to the queue.
@@ -38,7 +38,7 @@ sub result {
              || ($result->raw() =~ /^# Looks like you planned \d+ tests? but ran \d+/)
              || ($result->raw() =~ /^# Looks like your test died before it could output anything/)
            ) {
-        push @{$self->{queue} ||= []}, $result;
+        push @{$self->{_junit_queue} ||= []}, $result;
     }
 }
 
@@ -87,7 +87,7 @@ sub close_test {
     #                 may not have a plan issued, but should still be considered
     #                 a single error condition)
     my $testsrun = $parser->tests_run() || 0;
-    my $time     = $self->formatter->{timer} ? $self->_time_taken() : undef;
+    my $time     = $self->formatter->timer ? $self->_time_taken() : undef;
     my $failures = $parser->failed();
 
     my $noplan   = $parser->plan() ? 0 : 1;
@@ -119,7 +119,7 @@ sub close_test {
 sub dump_junit_xml {
     my ($self, $testsuite) = @_;
     if (my $spool_dir = $ENV{PERL_TEST_HARNESS_DUMP_TAP}) {
-        my $spool = File::Spec->catfile($spool_dir, $self->{name} . '.junit.xml');
+        my $spool = File::Spec->catfile($spool_dir, $self->name() . '.junit.xml');
 
         # clone the testsuite; XML::Generator only lets us auto-vivify the
         # CDATA sections *ONCE*.
@@ -178,11 +178,22 @@ sub _time_taken {
     return $t_diff;
 }
 
+###############################################################################
+# Calculate the time taken since the last test was seen in the TAP output.
+sub _time_since_last_test {
+    my $self = shift;
+    my $t_st = $self->{_junit_t_last_test} || $self->parser->start_time();
+    my $t_en = $self->get_time();
+    my $diff = $t_en - $t_st;
+    $self->{_junit_t_last_test} = $t_en;
+    return $diff;
+}
+
 ###############################################################################
 # Flushes the queue of test results, item by item.
 sub _flush_queue {
     my $self = shift;
-    my $queue = $self->{queue} ||= [];
+    my $queue = $self->{_junit_queue} ||= [];
     $self->_flush_item while @$queue;
 }
 
@@ -193,7 +204,7 @@ sub _flush_queue {
 # context or errors related to that test.
 sub _flush_item {
     my $self = shift;
-    my $queue = $self->{queue};
+    my $queue = $self->{_junit_queue};
 
     # get the result
     my $result = shift @$queue;
@@ -203,6 +214,7 @@ sub _flush_item {
     if ($result->is_test) {
         my %attrs = (
             'name' => _get_testcase_name($result),
+            ($self->formatter->timer ? ('time'=>$self->_time_since_last_test) : ()),
             );
 
         # slurp in all the content up to the next test
